Learn R Programming

mlrv (version 0.1.2)

MV_critical_cp: Statistics-adapted values for extended minimum volatility selection.

Description

Smoothing parameter selection for bootstrap tests for change point tests

Usage

MV_critical_cp(
  y,
  X,
  t,
  gridm,
  gridtau,
  cvalue = 0.1,
  B = 100L,
  lrvmethod = 1L,
  ind = 2L,
  rescale = 0L
)

Value

a matrix of critical values

Arguments

y,

vector, as used in the Heter_LRV

X,

matrix, covariates

t,

vector, time points.

gridm,

vector, a grid of candidate m's.

gridtau,

vector, a grid of candidate tau's.

cvalue,

double, 1-quantile for the calculation of bootstrap variance, default 0.1.

B,

integer, number of iterations for the calculation of bootstrap variance

lrvmethod,

integer, see also Heter_LRV

ind,

integer, the type of kernel, see also Heter_LRV

rescale,

bool, whether to rescale when positiveness of the matrix is not obtained. default 0

References

Bai, L., & Wu, W. (2024). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.

Examples

Run this code
n = 300
t = (1:n)/n
data = bregress2(n, 2, 1) # time series regression model with 2 changes points
critical = MV_critical_cp(data$y, data$x,t,  c(3,4,5), c(0.2,0.25, 0.3))

Run the code above in your browser using DataLab