Simulate data from time-varying time series regression model with change points
bregress2(nn, cp = 0, delta = 0, type = "norm")a list of data, x covariates, y response and e error. n = 300 data = bregress2(n, 2, 1) # time series regression model with 2 changes points
sample size
number of change points. If cp is between 0 and 1, it specifies the location of the single change point
double, magnitude of the jump
type of distributions of the innovations, default normal. It can also be "t4", "t5" and "t6".