Learn R Programming

mlrv (version 0.1.2)

heter_covariate: Long memory tests for non-stationary time series regression

Description

Test for long memory of e_i in the time series regression $$y_i = x_i \beta_i + e_i, 1\le i \le n$$ where x_i is the multivariate covariate process with first component 1, _i is the functional coefficient, e_i is the error term which can be long memory. In particular,covariates and the error term are allowed to be dependent.

Usage

heter_covariate(
  data,
  param = list(B = 2000, lrvmethod = 1, gcv = 1, neighbour = 1, lb = 3, ub = 11, tau_n =
    0.3, type = "KPSS"),
  mvselect = -1,
  bw = 0.2,
  shift = 1,
  verbose_dist = FALSE,
  hyper = FALSE
)

Value

p-value of the long memory test

Arguments

data

a list with the vector y and the matrix x, for example, list(x=...,y=...).

param

a list of parameters, list(B =..., lrvmethod =...,gcv = ..., neighbour =..., lb = ..., ub = ..., tau_n = ..., type = ..., ind = ...)

mvselect

the value of moving window parameter m. In addition, mvselect=-1 provides data-driven smoothing parameters via Minimum Volatility of the long-run covariance estimator as proposed in Chapter 9 of Politis et al.(1999), while mvselect = -2 provides data-driven smoothing parameters via Minimum Volatility of the bootstrap statistics, see Bai and Wu (2024a).

bw

the bandwidth parameter in the local linear regression, default 0.2.

shift

modify bw by a factor, default 1.

verbose_dist

whether to print intermediate results, i.e., the bootstrap distribution and statistics, default FALSE.

hyper

whether to only print the selected values of the smoothing parameters,m and _n, default FALSE.

mlrv functions

Heter_LRV, heter_covariate, heter_gradient, gcv_cov, MV_critical

Details

param

  • B, the number of bootstrap simulation, say 2000 *lrvmethod, the method of long-run variance estimation, lrvmethod = 0 uses the plug-in estimator in Zhou (2010), lrvmethod = 1 offers the debias difference-based estimator in Bai and Wu (2024b), lrvmethod = 2 provides the plug-in estimator using the , the pilot estimator proposed in Bai and Wu (2024b)

  • gcv, 1 or 0, whether to use Generalized Cross Validation for the selection of b, the bandwidth parameter in the local linear regression

  • neighbour, the number of neighbours in the extended minimum volatility, for example 1,2 or 3

  • lb, the lower bound of the range of m in the extended minimum volatility Selection

  • ub, the upper bound of the range of m in the extended minimum volatility Selection

  • bw_set, the proposed grid of the range of bandwidth selection. if not presented, a rule of thumb method will be used for the data-driven range

  • tau_n, the value of when no data-driven selection is used. if is set to 0, the rule of thumb n^-2/15 will be used

  • type, c( "KPSS","RS","VS","KS") type of tests, see Bai and Wu (2024a).

  • ind, types of kernels

  • 1 Triangular 1-|u|, u 1

  • 2 Epanechnikov kernel 3/4(1 - u^2), u 1

  • 3 Quartic 15/16(1 - u^2)^2, u 1

  • 4 Triweight 35/32(1 - u^2)^3, u 1

  • 5 Tricube 70/81(1 - |u|^3)^3, u 1

References

Bai, L., & Wu, W. (2024a). Detecting long-range dependence for time-varying linear models. Bernoulli, 30(3), 2450-2474.

Bai, L., & Wu, W. (2024b). Difference-based covariance matrix estimation in time series nonparametric regression with application to specification tests. Biometrika, asae013.

Zhou, Z. and Wu, W. B. (2010). Simultaneous inference of linear models with time varying coefficients.J. R. Stat. Soc. Ser. B. Stat. Methodol., 72(4):513–531.

Politis, D. N., Romano, J. P., and Wolf, M. (1999). Subsampling. Springer Science & Business Media.

Examples

Run this code
param = list(d = -0.2, heter = 2, tvd = 0,
 tw = 0.8, rate = 0.1, cur = 1,
 center = 0.3, ma_rate =  0, cov_tw =  0.2,
 cov_rate = 0.1, cov_center = 0.1, all_tw  = 1, cov_trend = 0.7)
data = Qct_reg(1000, param)
### KPSS test B
heter_covariate(data, list(B=20, lrvmethod = 1,
gcv = 1, neighbour = 1, lb = 3, ub = 11, type = "KPSS"), mvselect = -2, verbose_dist = TRUE)

Run the code above in your browser using DataLab